Page
Library
Module
Module type
Parameter
Class
Class type
If you are looking for more information regarding Catala, please visit https://catala-lang.org/
For more documentation or installation instructions, check out the Catala book: https://book.catala-lang.org/
In order to use this extension, you will need to install, opam, the OCaml package manager, in order to retrieve the LSP server.
If opam is not yet installed on your machine, please follow the instructions on their website. Do not forget to invoke opam init first.
In order to install the latest release of the VSCode extension and the Catala LSP server, please refer to the installation instructions in the Catala Book.
— and, optionally, you may also install the code formatter.
If you want to experiment with the latest version or build it directly from the sources you may use these instructions:
# 1. Clone this repository
git clone https://github.com/CatalaLang/catala-language-server.git
# 2. Enter the freshly created directory
cd catala-language-server/
# 3. Install the JS dependencies
npm install
# 4. Install the LSP dependencies
opam install . --deps-only
# 5. Build the extension
npm run compileFrom this point on, you may test the extension by skipping to the next section. Otherwise, you can package and install the extension in VSCode by following these extra steps:
# 1. Install VSCode extension CLI tool: e.g.,
sudo npm install -g @vscode/vsce
# 2. Package the extension
vsce package
# 3. Install the generated .vsix extension through the VSCode GUI or
# by invoking:
code --install-extension catala-XXXX.vsix
# Replace the XXXX with the current version
# 4. Install the LSP locally
opam install .If you wish to test the extension without installing it, you may:
$ code .)A new VSCode window should open with the extension running
Ctrl+r to reload the extension window to apply changesThe custom (visual) test case editor usage is controlled by a configuration setting. To enable or disable the custom editor:
When the custom editor is disabled, test files will open in the default text editor.
Note: After changing the setting, you must reload the VSCode window for the changes to take effect. This is because the custom editor registration happens when the extension is activated, and changing the setting doesn't automatically re-register or unregister the editor.
When developing on the "front" (typescript side) of the extension, you may invoke npm run watch to continuously build the extension.
All the code contained in this repository is released under the Apache license (version 2) unless another license is explicited for a sub-directory.
This extension is automatically published to the VS Code Marketplace when a new GitHub release is created.
Update Version in package.json:
package.jsonCreate a GitHub Release:
v0.23.0 or just 0.23.0)Automated Process: The CI/CD workflow automatically:
Verification: